import os
import sys
from fractions import Fraction
import pytest_check as check
from pyonfx import *

# Get ass path
dir_path = os.path.dirname(os.path.realpath(__file__))
path_ass = os.path.join(dir_path, "Ass", "in.ass")

# Extract infos from ass file
io = Ass(path_ass)
meta, styles, lines = io.get_data()

# Config
anime_fps = Fraction(24000, 1001)
max_deviation = 3


def test_coloralpha():
    # -- Test alpha conversion functions --
    assert Convert.alpha_ass_to_dec("&HFF&") == 255
    assert Convert.alpha_dec_to_ass(255) == "&HFF&"

    # -- Test conversion from and to rgba --
    assert Convert.color((0, 255, 0, 255), ColorModel.RGBA, ColorModel.RGBA) == (
        0,
        255,
        0,
        255,
    )
    assert (
        Convert.color("#00FF00FF", ColorModel.RGBA_STR, ColorModel.RGBA_STR)
        == "#00FF00FF"
    )

    # -- Test conversion to rgba --
    # Test ass (bgr) -> rgba conversion
    assert Convert.color("&H00FF00&", ColorModel.ASS, ColorModel.RGBA) == (
        0,
        255,
        0,
        255,
    )
    assert (
        Convert.color("&H00FF00&", ColorModel.ASS, ColorModel.RGBA_STR) == "#00FF00FF"
    )

    # Test ass (abgr) -> rgba conversion
    assert Convert.color("&HFF00FF00", ColorModel.ASS_STYLE, ColorModel.RGBA) == (
        0,
        255,
        0,
        255,
    )
    assert (
        Convert.color("&HFF00FF00", ColorModel.ASS_STYLE, ColorModel.RGBA_STR)
        == "#00FF00FF"
    )

    # Test rgb -> rgba conversion
    assert Convert.color((0, 255, 0), ColorModel.RGB, ColorModel.RGBA) == (
        0,
        255,
        0,
        255,
    )
    assert (
        Convert.color("#00FF00", ColorModel.RGB_STR, ColorModel.RGBA_STR) == "#00FF00FF"
    )

    # Test hsv -> rgba conversion
    assert Convert.color((0, 100, 100), ColorModel.HSV, ColorModel.RGBA) == (
        255,
        0,
        0,
        255,
    )
    assert (
        Convert.color((0, 100, 100), ColorModel.HSV, ColorModel.RGBA_STR) == "#FF0000FF"
    )
    assert Convert.color((0, 50, 100), ColorModel.HSV, ColorModel.RGBA) == (
        255,
        128,
        128,
        255,
    )
    assert (
        Convert.color((0, 50, 100), ColorModel.HSV, ColorModel.RGBA_STR) == "#FF8080FF"
    )
    assert Convert.color(
        (0, 50, 100), ColorModel.HSV, ColorModel.RGBA, round_output=False
    ) == (255.0, 127.5, 127.5, 255.0)

    # -- Test conversion from rgba --
    # Test rgba -> ass (bgr) conversion
    assert (
        Convert.color((0, 255, 0, 255), ColorModel.RGBA, ColorModel.ASS) == "&H00FF00&"
    )
    assert (
        Convert.color("#00FF00FF", ColorModel.RGBA_STR, ColorModel.ASS) == "&H00FF00&"
    )

    # Test rgba -> ass (abgr) conversion
    assert (
        Convert.color((0, 255, 0, 255), ColorModel.RGBA, ColorModel.ASS_STYLE)
        == "&HFF00FF00"
    )
    assert (
        Convert.color("#00FF00FF", ColorModel.RGBA_STR, ColorModel.ASS_STYLE)
        == "&HFF00FF00"
    )

    # Test rgba -> rgba conversion
    assert Convert.color((0, 255, 0, 255), ColorModel.RGBA, ColorModel.RGB) == (
        0,
        255,
        0,
    )
    assert (
        Convert.color("#00FF00FF", ColorModel.RGBA_STR, ColorModel.RGB_STR) == "#00FF00"
    )

    # Test rgba -> hsv conversion
    assert Convert.color((255, 0, 0, 255), ColorModel.RGBA, ColorModel.HSV) == (
        0,
        100,
        100,
    )
    assert Convert.color("#FF0000FF", ColorModel.RGBA_STR, ColorModel.HSV) == (
        0,
        100,
        100,
    )
    assert Convert.color(
        (0, 255 / 64, 255 / 64, 255), ColorModel.RGBA, ColorModel.HSV
    ) == (180, 100, 2)
    assert Convert.color(
        (0, 255 / 64, 255 / 64, 255),
        ColorModel.RGBA,
        ColorModel.HSV,
        round_output=False,
    ) == (180.0, 100.0, 1.5625)

    # -- Test color helper functions --
    # Test ass (bgr) -> rgb conversion
    assert Convert.color_ass_to_rgb("&H0000FF&") == (255, 0, 0)
    assert Convert.color_ass_to_rgb("&H0000FF&", as_str=True) == "#FF0000"

    # Test ass (bgr) -> hsv conversion
    assert Convert.color_ass_to_hsv("&H0000FF&") == (0, 100, 100)

    # Test rgb -> ass (bgr) conversion
    assert Convert.color_rgb_to_ass((255, 0, 0)) == "&H0000FF&"
    assert Convert.color_rgb_to_ass("#FF0000") == "&H0000FF&"

    # Test rgb -> hsv conversion
    assert Convert.color_rgb_to_hsv((255, 0, 0)) == (0, 100, 100)
    assert Convert.color_rgb_to_hsv("#FF0000") == (0, 100, 100)
    assert Convert.color_rgb_to_hsv((0, 255 / 64, 255 / 64)) == (180, 100, 2)
    assert Convert.color_rgb_to_hsv((0, 255 / 64, 255 / 64), round_output=False) == (
        180.0,
        100.0,
        1.5625,
    )

    # Test hsv -> ass (bgr) conversion
    assert Convert.color_hsv_to_ass((0, 100, 100)) == "&H0000FF&"

    # Test hsv -> rgb conversion
    assert Convert.color_hsv_to_rgb((0, 100, 100)) == (255, 0, 0)
    assert Convert.color_hsv_to_rgb((0, 100, 100), as_str=True) == "#FF0000"
    assert Convert.color_hsv_to_rgb((0, 50, 100)) == (255, 128, 128)
    assert Convert.color_hsv_to_rgb((0, 50, 100), as_str=True) == "#FF8080"
    assert Convert.color_hsv_to_rgb((0, 50, 100), round_output=False) == (
        255.0,
        127.5,
        127.5,
    )


def test_text_to_shape():
    shape = Convert.text_to_shape(lines[1].syls[0])

    if sys.platform == "win32":
        assert shape == Shape(
            "m 14.938 23.422 b 13 22.562 11.141 22.125 9.328 22.125 7.234 22.141 6.188 22.766 6.156 23.984 6.156 24.828 6.688 25.422 7.734 25.766 8.156 25.891 8.656 25.984 9.25 26.078 12.922 26.609 15.156 27.812 15.969 29.688 16.234 30.359 16.375 31.125 16.375 32 16.375 34.25 15.266 35.797 13.047 36.672 11.922 37.109 10.594 37.328 9.078 37.328 6.312 37.328 3.844 36.75 1.688 35.609 l 2.547 32.234 b 4.5 33.359 6.594 33.922 8.844 33.922 10.812 33.906 11.812 33.234 11.828 31.922 11.828 31.141 11.484 30.594 10.766 30.281 10.312 30.078 9.656 29.906 8.812 29.766 5.094 29.172 2.859 27.906 2.094 25.969 1.875 25.359 1.75 24.672 1.75 23.906 1.75 21.656 2.906 20.141 5.234 19.328 6.328 18.953 7.609 18.75 9.078 18.75 11.484 18.75 13.734 19.188 15.797 20.062 l 14.938 23.422 m 24.672 19.094 l 24.672 29.766 b 24.672 31.797 25.109 33.047 26.016 33.469 26.406 33.656 26.891 33.75 27.484 33.75 28.641 33.75 29.641 33.141 30.484 31.891 31.172 30.906 31.516 29.812 31.516 28.625 l 31.516 19.094 35.984 19.094 35.984 36.984 31.797 36.984 31.688 34.469 31.625 34.469 b 30.359 36.125 28.719 37.062 26.703 37.297 26.422 37.312 26.172 37.328 25.938 37.328 23.188 37.328 21.453 36.188 20.75 33.891 20.422 32.906 20.266 31.672 20.266 30.203 l 20.266 19.094 24.672 19.094"
        )
    elif sys.platform == "linux" or sys.platform == "darwin":
        i = 0
        expectedShape = Shape(
            "m 14.938 23.621 b 13.031 22.758 11.16 22.324 9.328 22.324 7.211 22.324 6.156 22.918 6.156 24.105 6.156 24.691 6.383 25.137 6.844 25.449 7.301 25.762 8.102 25.992 9.25 26.137 11.801 26.48 13.625 27.117 14.719 28.043 15.82 28.961 16.375 30.23 16.375 31.855 16.375 33.418 15.734 34.668 14.453 35.605 13.172 36.535 11.379 36.996 9.078 36.996 6.305 36.996 3.844 36.43 1.688 35.293 l 2.547 32.027 b 4.492 33.102 6.594 33.637 8.844 33.637 10.832 33.637 11.828 32.992 11.828 31.699 11.828 31.105 11.617 30.66 11.203 30.355 10.797 30.043 10 29.801 8.812 29.621 6.238 29.195 4.426 28.539 3.375 27.652 2.289 26.746 1.75 25.523 1.75 23.98 1.781 22.43 2.41 21.211 3.641 20.324 4.879 19.441 6.691 18.996 9.078 18.996 11.461 18.996 13.703 19.43 15.797 20.293 m 24.676 18.996 l 24.676 29.527 b 24.676 31.039 24.883 32.074 25.301 32.637 25.727 33.191 26.457 33.465 27.489 33.465 28.496 33.465 29.414 32.961 30.239 31.949 31.071 30.941 31.489 29.758 31.489 28.402 l 31.489 18.996 35.957 18.996 35.957 36.996 31.801 36.996 31.692 34.246 31.629 34.246 b 30.942 35.113 30.09 35.789 29.082 36.277 28.071 36.758 27.024 36.996 25.942 36.996 23.993 36.996 22.559 36.449 21.645 35.355 20.727 34.254 20.27 32.457 20.27 29.965 l 20.27 18.996"
        )
        for element, expected_element in zip(shape, expectedShape):
            for i in range(len(element.coordinates)):
                x, y = element.coordinates[i].x, element.coordinates[i].y
                x_expected, y_expected = (
                    expected_element.coordinates[i].x,
                    expected_element.coordinates[i].y,
                )
                check.almost_equal(x, x_expected, abs=max_deviation)
                check.almost_equal(y, y_expected, abs=max_deviation)
    else:
        raise NotImplementedError


def test_text_to_shape_with_spacing():
    path_ass_with_spacing = os.path.join(dir_path, "Ass", "in_with_spacing.ass")

    # Extract infos from ass file
    io_with_spacing = Ass(path_ass_with_spacing)
    _, _, lines_with_spacing = io_with_spacing.get_data()

    shape = Convert.text_to_shape(lines_with_spacing[1])

    print(shape)

    if sys.platform == "win32":
        assert shape == Shape(
            "m 14.938 23.422 b 13 22.562 11.141 22.125 9.328 22.125 7.234 22.141 6.188 22.766 6.156 23.984 6.156 24.828 6.688 25.422 7.734 25.766 8.156 25.891 8.656 25.984 9.25 26.078 12.922 26.609 15.156 27.812 15.969 29.688 16.234 30.359 16.375 31.125 16.375 32 16.375 34.25 15.266 35.797 13.047 36.672 11.922 37.109 10.594 37.328 9.078 37.328 6.312 37.328 3.844 36.75 1.688 35.609 l 2.547 32.234 b 4.5 33.359 6.594 33.922 8.844 33.922 10.812 33.906 11.812 33.234 11.828 31.922 11.828 31.141 11.484 30.594 10.766 30.281 10.312 30.078 9.656 29.906 8.812 29.766 5.094 29.172 2.859 27.906 2.094 25.969 1.875 25.359 1.75 24.672 1.75 23.906 1.75 21.656 2.906 20.141 5.234 19.328 6.328 18.953 7.609 18.75 9.078 18.75 11.484 18.75 13.734 19.188 15.797 20.062 l 14.938 23.422 m 26.672 19.094 l 26.672 29.766 b 26.672 31.797 27.109 33.047 28.016 33.469 28.406 33.656 28.891 33.75 29.484 33.75 30.641 33.75 31.641 33.141 32.484 31.891 33.172 30.906 33.516 29.812 33.516 28.625 l 33.516 19.094 37.984 19.094 37.984 36.984 33.797 36.984 33.688 34.469 33.625 34.469 b 32.359 36.125 30.719 37.062 28.703 37.297 28.422 37.312 28.172 37.328 27.938 37.328 25.188 37.328 23.453 36.188 22.75 33.891 22.422 32.906 22.266 31.672 22.266 30.203 l 22.266 19.094 26.672 19.094 m 44.734 19.094 l 49 19.094 49.062 22.531 49.141 22.531 b 51.203 20.016 53.938 18.75 57.359 18.75 l 57.359 22.391 b 53.875 22.391 51.484 23.5 50.203 25.703 49.609 26.703 49.312 27.875 49.312 29.172 l 49.312 36.984 44.734 36.984 44.734 19.094 m 66.688 29.656 b 66.844 31.578 67.766 32.906 69.438 33.609 70.156 33.906 70.938 34.062 71.781 34.062 73.5 34.031 75.188 33.609 76.844 32.781 l 77.875 35.953 b 75.781 36.875 73.609 37.328 71.328 37.328 68.188 37.328 65.781 36.25 64.109 34.094 62.844 32.469 62.219 30.453 62.219 28.047 62.219 24.422 63.406 21.797 65.797 20.156 67.219 19.219 68.922 18.75 70.891 18.75 74.578 18.75 77.094 20.203 78.422 23.125 79.016 24.5 79.312 26.109 79.312 27.938 79.312 28.516 79.281 29.078 79.219 29.656 l 66.688 29.656 m 66.688 26.594 l 75.078 26.594 b 75.062 24.047 74.062 22.562 72.094 22.125 71.719 22.031 71.328 21.984 70.922 21.984 68.922 21.984 67.625 22.906 67 24.734 66.812 25.312 66.719 25.938 66.688 26.594 l 66.688 26.594 m 98.172 32.719 l 99.203 36.062 b 97.328 36.906 95.375 37.328 93.359 37.328 89.969 37.328 87.406 36.203 85.688 33.953 84.453 32.359 83.828 30.375 83.828 28.047 83.828 24.281 85.188 21.625 87.891 20.062 89.406 19.188 91.219 18.75 93.359 18.75 95.375 18.75 97.328 19.172 99.203 20.016 l 98.172 23.422 b 96.703 22.609 95.172 22.188 93.562 22.188 91.094 22.188 89.484 23.297 88.75 25.5 88.516 26.25 88.406 27.094 88.406 28.047 88.406 30.516 89.234 32.266 90.906 33.266 91.688 33.734 92.578 33.953 93.562 33.953 95.219 33.938 96.75 33.516 98.172 32.719 l 98.172 32.719 m 105.781 11.188 l 110.25 11.188 110.25 21.406 110.328 21.406 b 111.812 19.656 113.641 18.781 115.828 18.75 118.656 18.75 120.453 19.984 121.266 22.469 121.656 23.641 121.844 25.109 121.844 26.906 l 121.844 36.984 117.438 36.984 117.438 27.344 b 117.438 24.875 117.016 23.344 116.172 22.734 115.719 22.438 115.078 22.297 114.281 22.297 113.062 22.297 112.031 22.969 111.188 24.328 110.562 25.312 110.25 26.359 110.25 27.453 l 110.25 36.984 105.781 36.984 105.781 11.188 m 129.453 36.984 l 129.453 19.094 134.172 19.094 134.172 36.984 129.453 36.984 m 129.453 15.312 l 129.453 11.188 134.172 11.188 134.172 15.312 129.453 15.312 m 145.219 27.703 b 145.219 30.156 145.938 31.812 147.391 32.688 147.969 33.031 148.578 33.203 149.25 33.203 151.016 33.203 152.234 32.359 152.922 30.656 153.25 29.859 153.406 28.922 153.406 27.875 l 153.406 27.531 b 153.406 25.047 152.625 23.406 151.062 22.609 150.5 22.328 149.891 22.188 149.25 22.188 147.281 22.188 146.031 23.266 145.5 25.391 145.312 26.078 145.219 26.844 145.219 27.703 l 145.219 27.703 m 147.969 18.75 b 150.297 18.781 152.156 19.719 153.547 21.609 l 153.609 21.609 153.719 19.094 157.875 19.094 157.875 35.156 b 157.844 41.625 154.703 44.875 148.484 44.906 146.406 44.906 144.453 44.562 142.641 43.859 l 143.438 40.5 b 145.109 41.188 146.766 41.531 148.391 41.531 150.688 41.531 152.172 40.734 152.859 39.156 153.266 38.188 153.484 36.891 153.484 35.266 l 153.484 33.984 153.406 33.984 b 152.078 35.766 150.266 36.641 147.969 36.641 145.703 36.641 143.906 35.672 142.578 33.719 141.469 32.094 140.922 30.078 140.922 27.703 140.922 23.562 142.172 20.844 144.672 19.5 145.641 19 146.734 18.75 147.969 18.75 l 147.969 18.75 m 167.969 31.719 b 167.969 32.953 168.531 33.719 169.641 33.984 169.906 34.031 170.156 34.062 170.406 34.062 172.062 34.062 173.344 33.438 174.266 32.172 174.781 31.391 175.047 30.531 175.047 29.594 l 175.047 28.422 173.562 28.422 b 170.719 28.422 168.953 29.125 168.234 30.547 168.047 30.922 167.969 31.312 167.969 31.719 l 167.969 31.719 m 171.844 18.75 b 175.453 18.75 177.75 19.734 178.766 21.703 179.266 22.703 179.516 23.969 179.516 25.531 l 179.516 32.172 b 179.516 33.797 179.688 35.406 180.031 36.984 l 175.812 36.984 b 175.672 36.203 175.562 35.328 175.5 34.344 l 175.422 34.344 b 174.297 35.984 172.625 36.969 170.406 37.266 170.016 37.312 169.641 37.328 169.266 37.328 166.906 37.328 165.281 36.469 164.391 34.75 163.969 33.969 163.766 33.078 163.766 32.062 163.766 29.547 165.031 27.703 167.547 26.562 169.172 25.828 171.188 25.453 173.562 25.453 l 175.047 25.453 175.047 25.359 b 175.047 23.781 174.609 22.781 173.703 22.391 173.219 22.188 172.578 22.094 171.75 22.094 169.5 22.094 167.375 22.609 165.375 23.641 l 164.734 20.297 b 166.906 19.266 169.281 18.75 171.844 18.75 l 171.844 18.75 m 190.672 19.094 l 190.672 29.766 b 190.672 31.797 191.109 33.047 192.016 33.469 192.406 33.656 192.891 33.75 193.484 33.75 194.641 33.75 195.641 33.141 196.484 31.891 197.172 30.906 197.516 29.812 197.516 28.625 l 197.516 19.094 201.984 19.094 201.984 36.984 197.797 36.984 197.688 34.469 197.625 34.469 b 196.359 36.125 194.719 37.062 192.703 37.297 192.422 37.312 192.172 37.328 191.938 37.328 189.188 37.328 187.453 36.188 186.75 33.891 186.422 32.906 186.266 31.672 186.266 30.203 l 186.266 19.094 190.672 19.094 m 225.906 29.078 l 225.828 29.078 225.828 36.984 221.359 36.984 221.359 11.188 225.828 11.188 225.828 26.078 225.906 26.078 232.719 19.094 238.047 19.094 229.547 27.594 238.219 36.984 232.891 36.984 225.906 29.078 m 251.609 33.922 b 253.781 33.922 255.172 32.781 255.766 30.516 255.953 29.781 256.047 28.953 256.047 28.047 256.047 24.891 255.031 23 253.016 22.359 252.578 22.219 252.109 22.156 251.609 22.156 249.391 22.156 248 23.344 247.453 25.703 247.281 26.406 247.203 27.188 247.203 28.047 247.203 31.234 248.219 33.125 250.266 33.75 250.703 33.859 251.156 33.922 251.609 33.922 l 251.609 33.922 m 251.609 18.75 b 254.906 18.75 257.359 19.938 258.938 22.297 260 23.875 260.516 25.797 260.516 28.047 260.516 31.531 259.344 34.094 257.016 35.75 255.516 36.797 253.719 37.328 251.609 37.328 248.281 37.328 245.844 36.141 244.281 33.75 243.25 32.172 242.734 30.266 242.734 28.047 242.734 24.516 243.906 21.922 246.234 20.297 247.734 19.266 249.516 18.75 251.609 18.75 l 251.609 18.75 m 273.5 19.781 l 279.656 19.781 279.656 23.125 273.5 23.125 273.5 30.453 b 273.5 32.219 273.844 33.281 274.531 33.641 274.844 33.812 275.297 33.891 275.875 33.891 276.969 33.891 278 33.688 278.969 33.297 l 279.547 36.641 b 278.125 37.094 276.594 37.328 274.938 37.328 272.094 37.328 270.266 36.422 269.469 34.609 269.094 33.734 268.922 32.609 268.922 31.234 l 268.922 23.125 265.203 23.125 265.203 19.781 268.922 19.781 268.922 13.25 273.5 13.25 273.5 19.781 m 294.078 33.922 b 296.25 33.922 297.641 32.781 298.234 30.516 298.422 29.781 298.516 28.953 298.516 28.047 298.516 24.891 297.5 23 295.484 22.359 295.047 22.219 294.578 22.156 294.078 22.156 291.859 22.156 290.469 23.344 289.922 25.703 289.75 26.406 289.672 27.188 289.672 28.047 289.672 31.234 290.688 33.125 292.734 33.75 293.172 33.859 293.625 33.922 294.078 33.922 l 294.078 33.922 m 294.078 18.75 b 297.375 18.75 299.828 19.938 301.406 22.297 302.469 23.875 302.984 25.797 302.984 28.047 302.984 31.531 301.812 34.094 299.484 35.75 297.984 36.797 296.188 37.328 294.078 37.328 290.75 37.328 288.312 36.141 286.75 33.75 285.719 32.172 285.203 30.266 285.203 28.047 285.203 24.516 286.375 21.922 288.703 20.297 290.203 19.266 291.984 18.75 294.078 18.75 l 294.078 18.75 m 321.359 28.047 b 321.359 24.672 320.281 22.766 318.094 22.328 317.812 22.281 317.531 22.266 317.234 22.266 315.578 22.266 314.422 23.109 313.719 24.812 313.359 25.672 313.172 26.703 313.172 27.875 l 313.172 28.219 b 313.172 30.875 313.969 32.609 315.547 33.406 316.078 33.688 316.641 33.828 317.234 33.812 318.906 33.828 320.109 32.953 320.812 31.234 321.188 30.344 321.359 29.281 321.359 28.047 l 321.359 28.047 m 308.703 11.188 l 313.172 11.188 313.172 21.406 313.25 21.406 b 314.625 19.641 316.375 18.75 318.516 18.75 321.562 18.75 323.656 20.156 324.797 22.984 325.375 24.375 325.672 26.062 325.672 28.047 325.672 31.938 324.547 34.656 322.297 36.188 321.188 36.953 319.938 37.328 318.516 37.328 316.219 37.312 314.391 36.359 313.031 34.469 l 312.969 34.469 312.906 36.984 308.703 36.984 308.703 11.188 m 334.734 31.719 b 334.734 32.953 335.297 33.719 336.406 33.984 336.672 34.031 336.922 34.062 337.172 34.062 338.828 34.062 340.109 33.438 341.031 32.172 341.547 31.391 341.812 30.531 341.812 29.594 l 341.812 28.422 340.328 28.422 b 337.484 28.422 335.719 29.125 335 30.547 334.812 30.922 334.734 31.312 334.734 31.719 l 334.734 31.719 m 338.609 18.75 b 342.219 18.75 344.516 19.734 345.531 21.703 346.031 22.703 346.281 23.969 346.281 25.531 l 346.281 32.172 b 346.281 33.797 346.453 35.406 346.797 36.984 l 342.578 36.984 b 342.438 36.203 342.328 35.328 342.266 34.344 l 342.188 34.344 b 341.062 35.984 339.391 36.969 337.172 37.266 336.781 37.312 336.406 37.328 336.031 37.328 333.672 37.328 332.047 36.469 331.156 34.75 330.734 33.969 330.531 33.078 330.531 32.062 330.531 29.547 331.797 27.703 334.312 26.562 335.938 25.828 337.953 25.453 340.328 25.453 l 341.812 25.453 341.812 25.359 b 341.812 23.781 341.375 22.781 340.469 22.391 339.984 22.188 339.344 22.094 338.516 22.094 336.266 22.094 334.141 22.609 332.141 23.641 l 331.5 20.297 b 333.672 19.266 336.047 18.75 338.609 18.75 l 338.609 18.75 m 365.656 19.094 l 369.859 19.094 369.922 21.609 369.984 21.609 b 371.234 20 372.844 19.078 374.844 18.812 375.141 18.781 375.422 18.75 375.703 18.75 378.531 18.75 380.328 19.984 381.141 22.469 381.531 23.641 381.719 25.109 381.719 26.906 l 381.719 36.984 377.312 36.984 377.312 27.344 b 377.312 24.875 376.891 23.344 376.047 22.734 375.594 22.438 374.953 22.297 374.156 22.297 373 22.297 372.016 22.906 371.156 24.156 370.469 25.156 370.125 26.266 370.125 27.453 l 370.125 36.984 365.656 36.984 365.656 19.094 m 395.969 33.922 b 398.141 33.922 399.531 32.781 400.125 30.516 400.312 29.781 400.406 28.953 400.406 28.047 400.406 24.891 399.391 23 397.375 22.359 396.938 22.219 396.469 22.156 395.969 22.156 393.75 22.156 392.359 23.344 391.812 25.703 391.641 26.406 391.562 27.188 391.562 28.047 391.562 31.234 392.578 33.125 394.625 33.75 395.062 33.859 395.516 33.922 395.969 33.922 l 395.969 33.922 m 395.969 18.75 b 399.266 18.75 401.719 19.938 403.297 22.297 404.359 23.875 404.875 25.797 404.875 28.047 404.875 31.531 403.703 34.094 401.375 35.75 399.875 36.797 398.078 37.328 395.969 37.328 392.641 37.328 390.203 36.141 388.641 33.75 387.609 32.172 387.094 30.266 387.094 28.047 387.094 24.516 388.266 21.922 390.594 20.297 392.094 19.266 393.875 18.75 395.969 18.75 l 395.969 18.75 m 427.109 19.094 l 427.109 29.766 b 427.109 31.797 427.547 33.047 428.453 33.469 428.844 33.656 429.328 33.75 429.922 33.75 431.078 33.75 432.078 33.141 432.922 31.891 433.609 30.906 433.953 29.812 433.953 28.625 l 433.953 19.094 438.422 19.094 438.422 36.984 434.234 36.984 434.125 34.469 434.062 34.469 b 432.797 36.125 431.156 37.062 429.141 37.297 428.859 37.312 428.609 37.328 428.375 37.328 425.625 37.328 423.891 36.188 423.188 33.891 422.859 32.906 422.703 31.672 422.703 30.203 l 422.703 19.094 427.109 19.094 m 445.172 19.094 l 449.438 19.094 449.5 22.531 449.578 22.531 b 451.641 20.016 454.375 18.75 457.797 18.75 l 457.797 22.391 b 454.312 22.391 451.922 23.5 450.641 25.703 450.047 26.703 449.75 27.875 449.75 29.172 l 449.75 36.984 445.172 36.984 445.172 19.094 m 467.203 31.719 b 467.203 32.953 467.766 33.719 468.875 33.984 469.141 34.031 469.391 34.062 469.641 34.062 471.297 34.062 472.578 33.438 473.5 32.172 474.016 31.391 474.281 30.531 474.281 29.594 l 474.281 28.422 472.797 28.422 b 469.953 28.422 468.188 29.125 467.469 30.547 467.281 30.922 467.203 31.312 467.203 31.719 l 467.203 31.719 m 471.078 18.75 b 474.688 18.75 476.984 19.734 478 21.703 478.5 22.703 478.75 23.969 478.75 25.531 l 478.75 32.172 b 478.75 33.797 478.922 35.406 479.266 36.984 l 475.047 36.984 b 474.906 36.203 474.797 35.328 474.734 34.344 l 474.656 34.344 b 473.531 35.984 471.859 36.969 469.641 37.266 469.25 37.312 468.875 37.328 468.5 37.328 466.141 37.328 464.516 36.469 463.625 34.75 463.203 33.969 463 33.078 463 32.062 463 29.547 464.266 27.703 466.781 26.562 468.406 25.828 470.422 25.453 472.797 25.453 l 474.281 25.453 474.281 25.359 b 474.281 23.781 473.844 22.781 472.938 22.391 472.453 22.188 471.812 22.094 470.984 22.094 468.734 22.094 466.609 22.609 464.609 23.641 l 463.969 20.297 b 466.141 19.266 468.516 18.75 471.078 18.75 l 471.078 18.75 m 498.125 19.094 l 502.328 19.094 502.391 21.609 502.453 21.609 b 503.703 20 505.312 19.078 507.312 18.812 507.609 18.781 507.891 18.75 508.172 18.75 511 18.75 512.797 19.984 513.609 22.469 514 23.641 514.188 25.109 514.188 26.906 l 514.188 36.984 509.781 36.984 509.781 27.344 b 509.781 24.875 509.359 23.344 508.516 22.734 508.062 22.438 507.422 22.297 506.625 22.297 505.469 22.297 504.484 22.906 503.625 24.156 502.938 25.156 502.594 26.266 502.594 27.453 l 502.594 36.984 498.125 36.984 498.125 19.094 m 521.797 36.984 l 521.797 19.094 526.516 19.094 526.516 36.984 521.797 36.984 m 521.797 15.312 l 521.797 11.188 526.516 11.188 526.516 15.312 521.797 15.312 m 554.188 19.781 l 560.344 19.781 560.344 23.125 554.188 23.125 554.188 30.453 b 554.188 32.219 554.531 33.281 555.219 33.641 555.531 33.812 555.984 33.891 556.562 33.891 557.656 33.891 558.688 33.688 559.656 33.297 l 560.234 36.641 b 558.812 37.094 557.281 37.328 555.625 37.328 552.781 37.328 550.953 36.422 550.156 34.609 549.781 33.734 549.609 32.609 549.609 31.234 l 549.609 23.125 545.891 23.125 545.891 19.781 549.609 19.781 549.609 13.25 554.188 13.25 554.188 19.781 m 574.766 33.922 b 576.938 33.922 578.328 32.781 578.922 30.516 579.109 29.781 579.203 28.953 579.203 28.047 579.203 24.891 578.188 23 576.172 22.359 575.734 22.219 575.266 22.156 574.766 22.156 572.547 22.156 571.156 23.344 570.609 25.703 570.438 26.406 570.359 27.188 570.359 28.047 570.359 31.234 571.375 33.125 573.422 33.75 573.859 33.859 574.312 33.922 574.766 33.922 l 574.766 33.922 m 574.766 18.75 b 578.062 18.75 580.516 19.938 582.094 22.297 583.156 23.875 583.672 25.797 583.672 28.047 583.672 31.531 582.5 34.094 580.172 35.75 578.672 36.797 576.875 37.328 574.766 37.328 571.438 37.328 569 36.141 567.438 33.75 566.406 32.172 565.891 30.266 565.891 28.047 565.891 24.516 567.062 21.922 569.391 20.297 570.891 19.266 572.672 18.75 574.766 18.75 l 574.766 18.75 m 594.828 33.641 l 604.016 33.641 604.016 36.984 589.219 36.984 589.219 33.641 598.406 22.5 598.406 22.438 589.219 22.438 589.219 19.094 604.016 19.094 604.016 22.438 594.828 33.578 594.828 33.641 m 614.109 31.719 b 614.109 32.953 614.672 33.719 615.781 33.984 616.047 34.031 616.297 34.062 616.547 34.062 618.203 34.062 619.484 33.438 620.406 32.172 620.922 31.391 621.188 30.531 621.188 29.594 l 621.188 28.422 619.703 28.422 b 616.859 28.422 615.094 29.125 614.375 30.547 614.188 30.922 614.109 31.312 614.109 31.719 l 614.109 31.719 m 617.984 18.75 b 621.594 18.75 623.891 19.734 624.906 21.703 625.406 22.703 625.656 23.969 625.656 25.531 l 625.656 32.172 b 625.656 33.797 625.828 35.406 626.172 36.984 l 621.953 36.984 b 621.812 36.203 621.703 35.328 621.641 34.344 l 621.562 34.344 b 620.438 35.984 618.766 36.969 616.547 37.266 616.156 37.312 615.781 37.328 615.406 37.328 613.047 37.328 611.422 36.469 610.531 34.75 610.109 33.969 609.906 33.078 609.906 32.062 609.906 29.547 611.172 27.703 613.688 26.562 615.312 25.828 617.328 25.453 619.703 25.453 l 621.188 25.453 621.188 25.359 b 621.188 23.781 620.75 22.781 619.844 22.391 619.359 22.188 618.719 22.094 617.891 22.094 615.641 22.094 613.516 22.609 611.516 23.641 l 610.875 20.297 b 613.047 19.266 615.422 18.75 617.984 18.75 l 617.984 18.75 m 645.141 23.422 b 643.203 22.562 641.344 22.125 639.531 22.125 637.438 22.141 636.391 22.766 636.359 23.984 636.359 24.828 636.891 25.422 637.938 25.766 638.359 25.891 638.859 25.984 639.453 26.078 643.125 26.609 645.359 27.812 646.172 29.688 646.438 30.359 646.578 31.125 646.578 32 646.578 34.25 645.469 35.797 643.25 36.672 642.125 37.109 640.797 37.328 639.281 37.328 636.516 37.328 634.047 36.75 631.891 35.609 l 632.75 32.234 b 634.703 33.359 636.797 33.922 639.047 33.922 641.016 33.906 642.016 33.234 642.031 31.922 642.031 31.141 641.688 30.594 640.969 30.281 640.516 30.078 639.859 29.906 639.016 29.766 635.297 29.172 633.062 27.906 632.297 25.969 632.078 25.359 631.953 24.672 631.953 23.906 631.953 21.656 633.109 20.141 635.438 19.328 636.531 18.953 637.812 18.75 639.281 18.75 641.688 18.75 643.938 19.188 646 20.062 l 645.141 23.422 m 655.984 31.719 b 655.984 32.953 656.547 33.719 657.656 33.984 657.922 34.031 658.172 34.062 658.422 34.062 660.078 34.062 661.359 33.438 662.281 32.172 662.797 31.391 663.062 30.531 663.062 29.594 l 663.062 28.422 661.578 28.422 b 658.734 28.422 656.969 29.125 656.25 30.547 656.062 30.922 655.984 31.312 655.984 31.719 l 655.984 31.719 m 659.859 18.75 b 663.469 18.75 665.766 19.734 666.781 21.703 667.281 22.703 667.531 23.969 667.531 25.531 l 667.531 32.172 b 667.531 33.797 667.703 35.406 668.047 36.984 l 663.828 36.984 b 663.688 36.203 663.578 35.328 663.516 34.344 l 663.438 34.344 b 662.312 35.984 660.641 36.969 658.422 37.266 658.031 37.312 657.656 37.328 657.281 37.328 654.922 37.328 653.297 36.469 652.406 34.75 651.984 33.969 651.781 33.078 651.781 32.062 651.781 29.547 653.047 27.703 655.562 26.562 657.188 25.828 659.203 25.453 661.578 25.453 l 663.062 25.453 663.062 25.359 b 663.062 23.781 662.625 22.781 661.719 22.391 661.234 22.188 660.594 22.094 659.766 22.094 657.516 22.094 655.391 22.609 653.391 23.641 l 652.75 20.297 b 654.922 19.266 657.297 18.75 659.859 18.75 l 659.859 18.75 m 674.453 19.094 l 678.719 19.094 678.781 22.531 678.859 22.531 b 680.922 20.016 683.656 18.75 687.078 18.75 l 687.078 22.391 b 683.594 22.391 681.203 23.5 679.922 25.703 679.328 26.703 679.031 27.875 679.031 29.172 l 679.031 36.984 674.453 36.984 674.453 19.094 m 696.406 29.656 b 696.562 31.578 697.484 32.906 699.156 33.609 699.875 33.906 700.656 34.062 701.5 34.062 703.219 34.031 704.906 33.609 706.562 32.781 l 707.594 35.953 b 705.5 36.875 703.328 37.328 701.047 37.328 697.906 37.328 695.5 36.25 693.828 34.094 692.562 32.469 691.938 30.453 691.938 28.047 691.938 24.422 693.125 21.797 695.516 20.156 696.938 19.219 698.641 18.75 700.609 18.75 704.297 18.75 706.812 20.203 708.141 23.125 708.734 24.5 709.031 26.109 709.031 27.938 709.031 28.516 709 29.078 708.938 29.656 l 696.406 29.656 m 696.406 26.594 l 704.797 26.594 b 704.781 24.047 703.781 22.562 701.812 22.125 701.438 22.031 701.047 21.984 700.641 21.984 698.641 21.984 697.344 22.906 696.719 24.734 696.531 25.312 696.438 25.938 696.406 26.594 l 696.406 26.594 m 722.188 19.781 l 728.344 19.781 728.344 23.125 722.188 23.125 722.188 30.453 b 722.188 32.219 722.531 33.281 723.219 33.641 723.531 33.812 723.984 33.891 724.562 33.891 725.656 33.891 726.688 33.688 727.656 33.297 l 728.234 36.641 b 726.812 37.094 725.281 37.328 723.625 37.328 720.781 37.328 718.953 36.422 718.156 34.609 717.781 33.734 717.609 32.609 717.609 31.234 l 717.609 23.125 713.891 23.125 713.891 19.781 717.609 19.781 717.609 13.25 722.188 13.25 722.188 19.781 m 738.438 31.719 b 738.438 32.953 739 33.719 740.109 33.984 740.375 34.031 740.625 34.062 740.875 34.062 742.531 34.062 743.812 33.438 744.734 32.172 745.25 31.391 745.516 30.531 745.516 29.594 l 745.516 28.422 744.031 28.422 b 741.188 28.422 739.422 29.125 738.703 30.547 738.516 30.922 738.438 31.312 738.438 31.719 l 738.438 31.719 m 742.312 18.75 b 745.922 18.75 748.219 19.734 749.234 21.703 749.734 22.703 749.984 23.969 749.984 25.531 l 749.984 32.172 b 749.984 33.797 750.156 35.406 750.5 36.984 l 746.281 36.984 b 746.141 36.203 746.031 35.328 745.969 34.344 l 745.891 34.344 b 744.766 35.984 743.094 36.969 740.875 37.266 740.484 37.312 740.109 37.328 739.734 37.328 737.375 37.328 735.75 36.469 734.859 34.75 734.438 33.969 734.234 33.078 734.234 32.062 734.234 29.547 735.5 27.703 738.016 26.562 739.641 25.828 741.656 25.453 744.031 25.453 l 745.516 25.453 745.516 25.359 b 745.516 23.781 745.078 22.781 744.172 22.391 743.688 22.188 743.047 22.094 742.219 22.094 739.969 22.094 737.844 22.609 735.844 23.641 l 735.203 20.297 b 737.375 19.266 739.75 18.75 742.312 18.75 l 742.312 18.75 m 774.078 29.078 l 774 29.078 774 36.984 769.531 36.984 769.531 11.188 774 11.188 774 26.078 774.078 26.078 780.891 19.094 786.219 19.094 777.719 27.594 786.391 36.984 781.062 36.984 774.078 29.078 m 799.781 33.922 b 801.953 33.922 803.344 32.781 803.938 30.516 804.125 29.781 804.219 28.953 804.219 28.047 804.219 24.891 803.203 23 801.188 22.359 800.75 22.219 800.281 22.156 799.781 22.156 797.562 22.156 796.172 23.344 795.625 25.703 795.453 26.406 795.375 27.188 795.375 28.047 795.375 31.234 796.391 33.125 798.438 33.75 798.875 33.859 799.328 33.922 799.781 33.922 l 799.781 33.922 m 799.781 18.75 b 803.078 18.75 805.531 19.938 807.109 22.297 808.172 23.875 808.688 25.797 808.688 28.047 808.688 31.531 807.516 34.094 805.188 35.75 803.688 36.797 801.891 37.328 799.781 37.328 796.453 37.328 794.016 36.141 792.453 33.75 791.422 32.172 790.906 30.266 790.906 28.047 790.906 24.516 792.078 21.922 794.406 20.297 795.906 19.266 797.688 18.75 799.781 18.75 l 799.781 18.75 m 818.953 29.078 l 818.875 29.078 818.875 36.984 814.406 36.984 814.406 11.188 818.875 11.188 818.875 26.078 818.953 26.078 825.766 19.094 831.094 19.094 822.594 27.594 831.266 36.984 825.938 36.984 818.953 29.078 m 844.656 33.922 b 846.828 33.922 848.219 32.781 848.812 30.516 849 29.781 849.094 28.953 849.094 28.047 849.094 24.891 848.078 23 846.062 22.359 845.625 22.219 845.156 22.156 844.656 22.156 842.438 22.156 841.047 23.344 840.5 25.703 840.328 26.406 840.25 27.188 840.25 28.047 840.25 31.234 841.266 33.125 843.312 33.75 843.75 33.859 844.203 33.922 844.656 33.922 l 844.656 33.922 m 844.656 18.75 b 847.953 18.75 850.406 19.938 851.984 22.297 853.047 23.875 853.562 25.797 853.562 28.047 853.562 31.531 852.391 34.094 850.062 35.75 848.562 36.797 846.766 37.328 844.656 37.328 841.328 37.328 838.891 36.141 837.328 33.75 836.297 32.172 835.781 30.266 835.781 28.047 835.781 24.516 836.953 21.922 839.281 20.297 840.781 19.266 842.562 18.75 844.656 18.75 l 844.656 18.75 m 859.109 19.094 l 863.375 19.094 863.438 22.531 863.516 22.531 b 865.578 20.016 868.312 18.75 871.734 18.75 l 871.734 22.391 b 868.25 22.391 865.859 23.5 864.578 25.703 863.984 26.703 863.688 27.875 863.688 29.172 l 863.688 36.984 859.109 36.984 859.109 19.094 m 885.469 33.922 b 887.641 33.922 889.031 32.781 889.625 30.516 889.812 29.781 889.906 28.953 889.906 28.047 889.906 24.891 888.891 23 886.875 22.359 886.438 22.219 885.969 22.156 885.469 22.156 883.25 22.156 881.859 23.344 881.312 25.703 881.141 26.406 881.062 27.188 881.062 28.047 881.062 31.234 882.078 33.125 884.125 33.75 884.562 33.859 885.016 33.922 885.469 33.922 l 885.469 33.922 m 885.469 18.75 b 888.766 18.75 891.219 19.938 892.797 22.297 893.859 23.875 894.375 25.797 894.375 28.047 894.375 31.531 893.203 34.094 890.875 35.75 889.375 36.797 887.578 37.328 885.469 37.328 882.141 37.328 879.703 36.141 878.141 33.75 877.109 32.172 876.594 30.266 876.594 28.047 876.594 24.516 877.766 21.922 880.094 20.297 881.594 19.266 883.375 18.75 885.469 18.75 l 885.469 18.75 m 912.375 19.094 l 916.578 19.094 916.641 21.609 916.703 21.609 b 917.953 20 919.562 19.078 921.562 18.812 921.859 18.781 922.141 18.75 922.422 18.75 925.25 18.75 927.047 19.984 927.859 22.469 928.25 23.641 928.438 25.109 928.438 26.906 l 928.438 36.984 924.031 36.984 924.031 27.344 b 924.031 24.875 923.609 23.344 922.766 22.734 922.312 22.438 921.672 22.297 920.875 22.297 919.719 22.297 918.734 22.906 917.875 24.156 917.188 25.156 916.844 26.266 916.844 27.453 l 916.844 36.984 912.375 36.984 912.375 19.094 m 942.688 33.922 b 944.859 33.922 946.25 32.781 946.844 30.516 947.031 29.781 947.125 28.953 947.125 28.047 947.125 24.891 946.109 23 944.094 22.359 943.656 22.219 943.188 22.156 942.688 22.156 940.469 22.156 939.078 23.344 938.531 25.703 938.359 26.406 938.281 27.188 938.281 28.047 938.281 31.234 939.297 33.125 941.344 33.75 941.781 33.859 942.234 33.922 942.688 33.922 l 942.688 33.922 m 942.688 18.75 b 945.984 18.75 948.438 19.938 950.016 22.297 951.078 23.875 951.594 25.797 951.594 28.047 951.594 31.531 950.422 34.094 948.094 35.75 946.594 36.797 944.797 37.328 942.688 37.328 939.359 37.328 936.922 36.141 935.359 33.75 934.328 32.172 933.812 30.266 933.812 28.047 933.812 24.516 934.984 21.922 937.312 20.297 938.812 19.266 940.594 18.75 942.688 18.75 l 942.688 18.75 m 974.312 29.078 l 974.234 29.078 974.234 36.984 969.766 36.984 969.766 11.188 974.234 11.188 974.234 26.078 974.312 26.078 981.125 19.094 986.453 19.094 977.953 27.594 986.625 36.984 981.297 36.984 974.312 29.078 m 995.688 31.719 b 995.688 32.953 996.25 33.719 997.359 33.984 997.625 34.031 997.875 34.062 998.125 34.062 999.781 34.062 1001.062 33.438 1001.984 32.172 1002.5 31.391 1002.766 30.531 1002.766 29.594 l 1002.766 28.422 1001.281 28.422 b 998.438 28.422 996.672 29.125 995.953 30.547 995.766 30.922 995.688 31.312 995.688 31.719 l 995.688 31.719 m 999.562 18.75 b 1003.172 18.75 1005.469 19.734 1006.484 21.703 1006.984 22.703 1007.234 23.969 1007.234 25.531 l 1007.234 32.172 b 1007.234 33.797 1007.406 35.406 1007.75 36.984 l 1003.531 36.984 b 1003.391 36.203 1003.281 35.328 1003.219 34.344 l 1003.141 34.344 b 1002.016 35.984 1000.344 36.969 998.125 37.266 997.734 37.312 997.359 37.328 996.984 37.328 994.625 37.328 993 36.469 992.109 34.75 991.688 33.969 991.484 33.078 991.484 32.062 991.484 29.547 992.75 27.703 995.266 26.562 996.891 25.828 998.906 25.453 1001.281 25.453 l 1002.766 25.453 1002.766 25.359 b 1002.766 23.781 1002.328 22.781 1001.422 22.391 1000.938 22.188 1000.297 22.094 999.469 22.094 997.219 22.094 995.094 22.609 993.094 23.641 l 992.453 20.297 b 994.625 19.266 997 18.75 999.562 18.75 l 999.562 18.75 m 1017.422 27.703 b 1017.422 30.156 1018.141 31.812 1019.594 32.688 1020.172 33.031 1020.781 33.203 1021.453 33.203 1023.219 33.203 1024.438 32.359 1025.125 30.656 1025.453 29.859 1025.609 28.922 1025.609 27.875 l 1025.609 27.531 b 1025.609 25.047 1024.828 23.406 1023.266 22.609 1022.703 22.328 1022.094 22.188 1021.453 22.188 1019.484 22.188 1018.234 23.266 1017.703 25.391 1017.516 26.078 1017.422 26.844 1017.422 27.703 l 1017.422 27.703 m 1020.172 18.75 b 1022.5 18.781 1024.359 19.719 1025.75 21.609 l 1025.812 21.609 1025.922 19.094 1030.078 19.094 1030.078 35.156 b 1030.047 41.625 1026.906 44.875 1020.688 44.906 1018.609 44.906 1016.656 44.562 1014.844 43.859 l 1015.641 40.5 b 1017.312 41.188 1018.969 41.531 1020.594 41.531 1022.891 41.531 1024.375 40.734 1025.062 39.156 1025.469 38.188 1025.688 36.891 1025.688 35.266 l 1025.688 33.984 1025.609 33.984 b 1024.281 35.766 1022.469 36.641 1020.172 36.641 1017.906 36.641 1016.109 35.672 1014.781 33.719 1013.672 32.094 1013.125 30.078 1013.125 27.703 1013.125 23.562 1014.375 20.844 1016.875 19.5 1017.844 19 1018.938 18.75 1020.172 18.75 l 1020.172 18.75 m 1037.859 36.984 l 1037.859 19.094 1042.578 19.094 1042.578 36.984 1037.859 36.984 m 1037.859 15.312 l 1037.859 11.188 1042.578 11.188 1042.578 15.312 1037.859 15.312"
        )
    elif sys.platform == "linux" or sys.platform == "darwin":
        i = 0
        expectedShape = Shape(
            "m 14.922 23.656 b 12.992 22.793 11.125 22.359 9.312 22.359 7.227 22.359 6.176 22.945 6.156 24.109 6.156 24.934 6.68 25.512 7.734 25.844 8.148 25.961 8.656 26.055 9.25 26.125 12.914 26.637 15.148 27.797 15.953 29.609 16.234 30.258 16.375 31 16.375 31.844 16.375 34.012 15.258 35.512 13.031 36.344 11.906 36.773 10.586 36.984 9.078 36.984 6.305 36.984 3.844 36.418 1.688 35.281 l 2.547 32.016 b 4.492 33.09 6.594 33.625 8.844 33.625 10.812 33.625 11.805 32.996 11.828 31.734 11.828 30.984 11.473 30.453 10.766 30.141 10.305 29.945 9.648 29.777 8.797 29.641 5.086 29.059 2.852 27.84 2.094 25.984 1.863 25.383 1.75 24.715 1.75 23.984 1.75 21.809 2.91 20.328 5.234 19.547 6.328 19.172 7.609 18.984 9.078 18.984 11.484 18.984 13.719 19.418 15.781 20.281 m 26.67 18.984 l 26.67 29.719 b 26.67 31.773 27.111 33.016 27.998 33.453 28.392 33.641 28.888 33.734 29.482 33.734 30.627 33.734 31.627 33.109 32.482 31.859 33.17 30.871 33.513 29.777 33.513 28.578 l 33.513 18.984 37.982 18.984 37.982 36.984 33.779 36.984 33.685 34.453 33.607 34.453 b 32.345 35.922 30.705 36.758 28.685 36.953 28.412 36.977 28.162 36.984 27.935 36.984 25.185 36.984 23.455 35.852 22.748 33.578 22.423 32.609 22.263 31.402 22.263 29.953 l 22.263 18.984 m 44.723 18.984 l 48.989 18.984 49.052 22.734 49.13 22.734 b 51.192 20.234 53.931 18.984 57.348 18.984 l 57.348 22.594 b 53.856 22.594 51.473 23.68 50.192 25.844 49.598 26.844 49.302 27.992 49.302 29.281 l 49.302 36.984 44.723 36.984 m 66.672 29 b 66.828 31.086 67.742 32.508 69.422 33.266 70.129 33.59 70.91 33.75 71.766 33.75 73.485 33.75 75.164 33.293 76.813 32.375 l 77.844 35.625 b 75.758 36.531 73.582 36.984 71.313 36.984 68.176 36.984 65.77 35.938 64.094 33.844 62.832 32.273 62.203 30.32 62.203 27.984 62.203 24.477 63.395 21.934 65.781 20.359 67.196 19.445 68.891 18.984 70.86 18.984 74.555 18.984 77.071 20.324 78.406 23 79 24.273 79.297 25.75 79.297 27.438 79.297 27.961 79.258 28.48 79.188 29 m 66.672 25.984 l 75.063 25.984 b 75.039 23.891 74.047 22.664 72.078 22.297 71.703 22.227 71.313 22.188 70.906 22.188 68.906 22.188 67.598 22.945 66.985 24.453 66.797 24.922 66.692 25.434 66.672 25.984 m 98.152 32.469 l 99.184 35.734 b 97.297 36.57 95.348 36.984 93.34 36.984 89.941 36.984 87.387 35.898 85.668 33.719 84.426 32.168 83.809 30.258 83.809 27.984 83.809 24.352 85.16 21.773 87.871 20.25 89.379 19.406 91.203 18.984 93.34 18.984 95.348 18.984 97.297 19.406 99.184 20.25 l 98.152 23.578 b 96.684 22.789 95.145 22.391 93.543 22.391 91.063 22.391 89.457 23.445 88.731 25.547 88.5 26.277 88.387 27.09 88.387 27.984 88.387 30.359 89.219 32.027 90.887 32.984 91.668 33.434 92.551 33.656 93.543 33.656 95.188 33.656 96.723 33.262 98.152 32.469 m 105.759 11.984 l 110.228 11.984 110.228 21.562 110.29 21.562 b 111.778 19.844 113.618 18.984 115.806 18.984 118.618 18.984 120.423 20.211 121.228 22.656 121.622 23.812 121.821 25.273 121.821 27.031 l 121.821 36.984 117.415 36.984 117.415 27.453 b 117.415 24.996 116.993 23.469 116.15 22.875 115.689 22.586 115.06 22.438 114.259 22.438 113.04 22.438 112.001 23.105 111.15 24.438 110.532 25.43 110.228 26.465 110.228 27.547 l 110.228 36.984 105.759 36.984 m 129.433 36.984 l 129.433 18.984 134.136 18.984 134.136 36.984 m 129.433 16.062 l 129.433 11.984 134.136 11.984 134.136 16.062 m 145.189 27.953 b 145.189 30.477 145.911 32.18 147.36 33.062 147.931 33.418 148.548 33.594 149.204 33.594 150.974 33.594 152.204 32.727 152.892 30.984 153.212 30.164 153.376 29.215 153.376 28.141 l 153.376 27.797 b 153.376 25.266 152.595 23.59 151.032 22.766 150.458 22.484 149.849 22.344 149.204 22.344 147.235 22.344 145.989 23.434 145.47 25.609 145.282 26.32 145.189 27.102 145.189 27.953 m 147.939 18.984 b 150.251 18.984 152.11 19.891 153.517 21.703 l 153.579 21.703 153.689 18.984 157.845 18.984 157.845 34.578 b 157.802 40.848 154.673 43.984 148.454 43.984 146.368 43.984 144.423 43.645 142.61 42.969 l 143.407 39.875 b 145.071 40.395 146.72 40.656 148.345 40.656 150.646 40.656 152.142 39.992 152.829 38.672 153.235 37.867 153.439 36.793 153.439 35.438 l 153.439 34.375 153.376 34.375 b 152.04 36.117 150.228 36.984 147.939 36.984 145.665 36.984 143.864 36.008 142.532 34.047 141.439 32.402 140.892 30.383 140.892 27.984 140.892 23.828 142.142 21.086 144.642 19.75 145.599 19.242 146.696 18.984 147.939 18.984 m 167.92 31.469 b 167.92 32.762 168.483 33.555 169.608 33.844 169.858 33.887 170.111 33.906 170.373 33.906 172.018 33.906 173.299 33.246 174.217 31.922 174.748 31.109 175.014 30.211 175.014 29.219 l 175.014 27.984 173.529 27.984 b 170.686 27.984 168.908 28.734 168.201 30.234 168.014 30.609 167.92 31.023 167.92 31.469 m 171.811 18.984 b 175.412 18.984 177.717 19.961 178.717 21.906 179.225 22.887 179.483 24.141 179.483 25.672 l 179.483 32.234 b 179.483 33.84 179.654 35.422 179.998 36.984 l 175.764 36.984 b 175.627 36.164 175.522 35.234 175.451 34.203 l 175.389 34.203 b 174.264 35.734 172.592 36.637 170.373 36.906 169.975 36.961 169.596 36.984 169.233 36.984 166.865 36.984 165.236 36.121 164.342 34.391 163.936 33.609 163.733 32.711 163.733 31.688 163.733 29.156 164.99 27.32 167.514 26.172 169.139 25.434 171.143 25.062 173.529 25.062 l 175.014 25.062 175.014 24.984 b 175.014 23.684 174.565 22.871 173.67 22.547 173.19 22.371 172.533 22.281 171.701 22.281 169.459 22.281 167.342 22.711 165.342 23.562 l 164.686 20.516 b 166.873 19.496 169.248 18.984 171.811 18.984 m 190.633 18.984 l 190.633 29.719 b 190.633 31.773 191.075 33.016 191.961 33.453 192.356 33.641 192.852 33.734 193.446 33.734 194.59 33.734 195.59 33.109 196.446 31.859 197.133 30.871 197.477 29.777 197.477 28.578 l 197.477 18.984 201.946 18.984 201.946 36.984 197.743 36.984 197.649 34.453 197.571 34.453 b 196.309 35.922 194.668 36.758 192.649 36.953 192.375 36.977 192.125 36.984 191.899 36.984 189.149 36.984 187.418 35.852 186.711 33.578 186.387 32.609 186.227 31.402 186.227 29.953 l 186.227 18.984 m 225.848 29.016 l 225.785 29.016 225.785 36.984 221.317 36.984 221.317 11.984 225.785 11.984 225.785 26.016 225.848 26.016 232.66 18.984 237.989 18.984 229.504 27.531 238.16 36.984 232.832 36.984 m 251.553 33.625 b 253.729 33.625 255.115 32.539 255.709 30.359 255.897 29.652 255.99 28.859 255.99 27.984 255.99 24.977 254.979 23.168 252.959 22.562 252.522 22.43 252.053 22.359 251.553 22.359 249.322 22.359 247.932 23.484 247.381 25.734 247.225 26.422 247.147 27.172 247.147 27.984 247.147 31.039 248.166 32.859 250.209 33.453 250.647 33.57 251.092 33.625 251.553 33.625 m 251.553 18.984 b 254.854 18.984 257.295 20.133 258.881 22.422 259.932 23.953 260.459 25.809 260.459 27.984 260.459 31.359 259.287 33.852 256.943 35.453 255.451 36.477 253.654 36.984 251.553 36.984 248.229 36.984 245.787 35.828 244.225 33.516 243.193 31.984 242.678 30.141 242.678 27.984 242.678 24.559 243.842 22.059 246.178 20.484 247.666 19.484 249.459 18.984 251.553 18.984 m 273.423 19.703 l 279.579 19.703 279.579 22.984 273.423 22.984 273.423 30.203 b 273.423 31.934 273.767 32.98 274.454 33.344 274.775 33.5 275.224 33.578 275.798 33.578 276.9 33.578 277.931 33.387 278.892 33 l 279.486 36.297 b 278.056 36.758 276.521 36.984 274.876 36.984 272.033 36.984 270.208 36.09 269.408 34.297 269.04 33.453 268.861 32.352 268.861 30.984 l 268.861 22.984 265.142 22.984 265.142 19.703 268.861 19.703 268.861 12.984 273.423 12.984 m 294.002 33.625 b 296.178 33.625 297.565 32.539 298.158 30.359 298.346 29.652 298.44 28.859 298.44 27.984 298.44 24.977 297.428 23.168 295.408 22.562 294.971 22.43 294.502 22.359 294.002 22.359 291.772 22.359 290.381 23.484 289.83 25.734 289.674 26.422 289.596 27.172 289.596 27.984 289.596 31.039 290.615 32.859 292.658 33.453 293.096 33.57 293.541 33.625 294.002 33.625 m 294.002 18.984 b 297.303 18.984 299.744 20.133 301.33 22.422 302.381 23.953 302.908 25.809 302.908 27.984 302.908 31.359 301.736 33.852 299.393 35.453 297.901 36.477 296.104 36.984 294.002 36.984 290.678 36.984 288.236 35.828 286.674 33.516 285.643 31.984 285.127 30.141 285.127 27.984 285.127 24.559 286.291 22.059 288.627 20.484 290.115 19.484 291.908 18.984 294.002 18.984 m 321.279 27.984 b 321.279 24.766 320.189 22.945 318.013 22.516 317.732 22.477 317.443 22.453 317.154 22.453 315.497 22.453 314.326 23.266 313.638 24.891 313.271 25.727 313.091 26.699 313.091 27.812 l 313.091 28.156 b 313.091 30.699 313.88 32.355 315.466 33.125 315.986 33.387 316.548 33.516 317.154 33.516 318.818 33.516 320.013 32.695 320.732 31.047 321.095 30.184 321.279 29.164 321.279 27.984 m 308.622 11.984 l 313.091 11.984 313.091 21.609 313.154 21.609 b 314.529 19.859 316.283 18.984 318.419 18.984 321.47 18.984 323.568 20.355 324.716 23.094 325.287 24.449 325.576 26.078 325.576 27.984 325.576 31.758 324.451 34.387 322.201 35.875 321.107 36.617 319.845 36.984 318.419 36.984 316.126 36.984 314.302 36.07 312.951 34.234 l 312.888 34.234 312.81 36.984 308.622 36.984 m 334.627 31.469 b 334.627 32.762 335.189 33.555 336.314 33.844 336.564 33.887 336.818 33.906 337.08 33.906 338.725 33.906 340.006 33.246 340.924 31.922 341.455 31.109 341.721 30.211 341.721 29.219 l 341.721 27.984 340.236 27.984 b 337.392 27.984 335.615 28.734 334.908 30.234 334.721 30.609 334.627 31.023 334.627 31.469 m 338.517 18.984 b 342.119 18.984 344.424 19.961 345.424 21.906 345.932 22.887 346.189 24.141 346.189 25.672 l 346.189 32.234 b 346.189 33.84 346.361 35.422 346.705 36.984 l 342.471 36.984 b 342.334 36.164 342.228 35.234 342.158 34.203 l 342.096 34.203 b 340.971 35.734 339.299 36.637 337.08 36.906 336.682 36.961 336.303 36.984 335.939 36.984 333.572 36.984 331.943 36.121 331.049 34.391 330.642 33.609 330.439 32.711 330.439 31.688 330.439 29.156 331.697 27.32 334.221 26.172 335.846 25.434 337.85 25.062 340.236 25.062 l 341.721 25.062 341.721 24.984 b 341.721 23.684 341.271 22.871 340.377 22.547 339.896 22.371 339.24 22.281 338.408 22.281 336.166 22.281 334.049 22.711 332.049 23.562 l 331.392 20.516 b 333.58 19.496 335.955 18.984 338.517 18.984 m 365.563 18.984 l 369.751 18.984 369.829 21.516 369.891 21.516 b 371.13 20.102 372.751 19.277 374.751 19.047 375.04 19.008 375.329 18.984 375.61 18.984 378.423 18.984 380.227 20.211 381.032 22.656 381.427 23.812 381.626 25.273 381.626 27.031 l 381.626 36.984 377.219 36.984 377.219 27.297 b 377.219 24.809 376.798 23.262 375.954 22.656 375.493 22.355 374.864 22.203 374.063 22.203 372.907 22.203 371.907 22.828 371.063 24.078 370.376 25.09 370.032 26.195 370.032 27.391 l 370.032 36.984 365.563 36.984 m 395.871 33.625 b 398.046 33.625 399.433 32.539 400.027 30.359 400.214 29.652 400.308 28.859 400.308 27.984 400.308 24.977 399.296 23.168 397.277 22.562 396.839 22.43 396.371 22.359 395.871 22.359 393.64 22.359 392.249 23.484 391.699 25.734 391.542 26.422 391.464 27.172 391.464 27.984 391.464 31.039 392.484 32.859 394.527 33.453 394.964 33.57 395.41 33.625 395.871 33.625 m 395.871 18.984 b 399.171 18.984 401.613 20.133 403.199 22.422 404.249 23.953 404.777 25.809 404.777 27.984 404.777 31.359 403.605 33.852 401.261 35.453 399.769 36.477 397.972 36.984 395.871 36.984 392.546 36.984 390.105 35.828 388.542 33.516 387.511 31.984 386.996 30.141 386.996 27.984 386.996 24.559 388.16 22.059 390.496 20.484 391.984 19.484 393.777 18.984 395.871 18.984 m 427.011 18.984 l 427.011 29.719 b 427.011 31.773 427.452 33.016 428.339 33.453 428.734 33.641 429.23 33.734 429.824 33.734 430.968 33.734 431.968 33.109 432.824 31.859 433.511 30.871 433.855 29.777 433.855 28.578 l 433.855 18.984 438.324 18.984 438.324 36.984 434.12 36.984 434.027 34.453 433.949 34.453 b 432.687 35.922 431.046 36.758 429.027 36.953 428.753 36.977 428.503 36.984 428.277 36.984 425.527 36.984 423.796 35.852 423.089 33.578 422.765 32.609 422.605 31.402 422.605 29.953 l 422.605 18.984 m 445.065 18.984 l 449.331 18.984 449.393 22.734 449.471 22.734 b 451.534 20.234 454.272 18.984 457.69 18.984 l 457.69 22.594 b 454.198 22.594 451.815 23.68 450.534 25.844 449.94 26.844 449.643 27.992 449.643 29.281 l 449.643 36.984 445.065 36.984 m 467.076 31.469 b 467.076 32.762 467.639 33.555 468.764 33.844 469.014 33.887 469.268 33.906 469.529 33.906 471.174 33.906 472.455 33.246 473.373 31.922 473.904 31.109 474.17 30.211 474.17 29.219 l 474.17 27.984 472.685 27.984 b 469.842 27.984 468.064 28.734 467.357 30.234 467.17 30.609 467.076 31.023 467.076 31.469 m 470.967 18.984 b 474.568 18.984 476.873 19.961 477.873 21.906 478.381 22.887 478.639 24.141 478.639 25.672 l 478.639 32.234 b 478.639 33.84 478.81 35.422 479.154 36.984 l 474.92 36.984 b 474.783 36.164 474.678 35.234 474.607 34.203 l 474.545 34.203 b 473.42 35.734 471.748 36.637 469.529 36.906 469.131 36.961 468.752 36.984 468.389 36.984 466.021 36.984 464.393 36.121 463.498 34.391 463.092 33.609 462.889 32.711 462.889 31.688 462.889 29.156 464.146 27.32 466.67 26.172 468.295 25.434 470.299 25.062 472.685 25.062 l 474.17 25.062 474.17 24.984 b 474.17 23.684 473.721 22.871 472.826 22.547 472.346 22.371 471.689 22.281 470.857 22.281 468.615 22.281 466.498 22.711 464.498 23.562 l 463.842 20.516 b 466.029 19.496 468.404 18.984 470.967 18.984 m 498.013 18.984 l 502.2 18.984 502.278 21.516 502.341 21.516 b 503.579 20.102 505.2 19.277 507.2 19.047 507.489 19.008 507.778 18.984 508.059 18.984 510.872 18.984 512.677 20.211 513.481 22.656 513.876 23.812 514.075 25.273 514.075 27.031 l 514.075 36.984 509.669 36.984 509.669 27.297 b 509.669 24.809 509.247 23.262 508.403 22.656 507.942 22.355 507.313 22.203 506.513 22.203 505.356 22.203 504.356 22.828 503.513 24.078 502.825 25.09 502.481 26.195 502.481 27.391 l 502.481 36.984 498.013 36.984 m 521.679 36.984 l 521.679 18.984 526.382 18.984 526.382 36.984 m 521.679 16.062 l 521.679 11.984 526.382 11.984 526.382 16.062 m 554.049 19.703 l 560.205 19.703 560.205 22.984 554.049 22.984 554.049 30.203 b 554.049 31.934 554.393 32.98 555.08 33.344 555.4 33.5 555.85 33.578 556.424 33.578 557.525 33.578 558.557 33.387 559.518 33 l 560.111 36.297 b 558.682 36.758 557.146 36.984 555.502 36.984 552.658 36.984 550.834 36.09 550.033 34.297 549.666 33.453 549.486 32.352 549.486 30.984 l 549.486 22.984 545.768 22.984 545.768 19.703 549.486 19.703 549.486 12.984 554.049 12.984 m 574.628 33.625 b 576.803 33.625 578.19 32.539 578.784 30.359 578.971 29.652 579.065 28.859 579.065 27.984 579.065 24.977 578.053 23.168 576.034 22.562 575.596 22.43 575.128 22.359 574.628 22.359 572.397 22.359 571.007 23.484 570.456 25.734 570.3 26.422 570.221 27.172 570.221 27.984 570.221 31.039 571.241 32.859 573.284 33.453 573.721 33.57 574.167 33.625 574.628 33.625 m 574.628 18.984 b 577.928 18.984 580.37 20.133 581.956 22.422 583.007 23.953 583.534 25.809 583.534 27.984 583.534 31.359 582.362 33.852 580.018 35.453 578.526 36.477 576.729 36.984 574.628 36.984 571.303 36.984 568.862 35.828 567.3 33.516 566.268 31.984 565.753 30.141 565.753 27.984 565.753 24.559 566.917 22.059 569.253 20.484 570.741 19.484 572.534 18.984 574.628 18.984 m 594.686 33.656 l 603.857 33.656 603.857 36.984 589.076 36.984 589.076 33.688 598.264 22.312 589.076 22.312 589.076 18.984 603.857 18.984 603.857 22.281 m 613.942 31.469 b 613.942 32.762 614.505 33.555 615.63 33.844 615.88 33.887 616.134 33.906 616.396 33.906 618.04 33.906 619.321 33.246 620.239 31.922 620.771 31.109 621.036 30.211 621.036 29.219 l 621.036 27.984 619.552 27.984 b 616.708 27.984 614.931 28.734 614.224 30.234 614.036 30.609 613.942 31.023 613.942 31.469 m 617.833 18.984 b 621.435 18.984 623.739 19.961 624.739 21.906 625.247 22.887 625.505 24.141 625.505 25.672 l 625.505 32.234 b 625.505 33.84 625.677 35.422 626.021 36.984 l 621.786 36.984 b 621.649 36.164 621.544 35.234 621.474 34.203 l 621.411 34.203 b 620.286 35.734 618.614 36.637 616.396 36.906 615.997 36.961 615.618 36.984 615.255 36.984 612.888 36.984 611.259 36.121 610.364 34.391 609.958 33.609 609.755 32.711 609.755 31.688 609.755 29.156 611.013 27.32 613.536 26.172 615.161 25.434 617.165 25.062 619.552 25.062 l 621.036 25.062 621.036 24.984 b 621.036 23.684 620.587 22.871 619.692 22.547 619.212 22.371 618.556 22.281 617.724 22.281 615.482 22.281 613.364 22.711 611.364 23.562 l 610.708 20.516 b 612.896 19.496 615.271 18.984 617.833 18.984 m 644.968 23.656 b 643.038 22.793 641.171 22.359 639.359 22.359 637.273 22.359 636.222 22.945 636.202 24.109 636.202 24.934 636.726 25.512 637.781 25.844 638.195 25.961 638.702 26.055 639.296 26.125 642.96 26.637 645.195 27.797 645.999 29.609 646.281 30.258 646.421 31 646.421 31.844 646.421 34.012 645.304 35.512 643.077 36.344 641.952 36.773 640.632 36.984 639.124 36.984 636.351 36.984 633.89 36.418 631.734 35.281 l 632.593 32.016 b 634.538 33.09 636.64 33.625 638.89 33.625 640.859 33.625 641.851 32.996 641.874 31.734 641.874 30.984 641.519 30.453 640.812 30.141 640.351 29.945 639.695 29.777 638.843 29.641 635.132 29.059 632.898 27.84 632.14 25.984 631.909 25.383 631.796 24.715 631.796 23.984 631.796 21.809 632.956 20.328 635.281 19.547 636.374 19.172 637.656 18.984 639.124 18.984 641.531 18.984 643.765 19.418 645.827 20.281 m 655.809 31.469 b 655.809 32.762 656.372 33.555 657.497 33.844 657.747 33.887 658.001 33.906 658.263 33.906 659.907 33.906 661.188 33.246 662.106 31.922 662.638 31.109 662.903 30.211 662.903 29.219 l 662.903 27.984 661.419 27.984 b 658.575 27.984 656.798 28.734 656.091 30.234 655.903 30.609 655.809 31.023 655.809 31.469 m 659.7 18.984 b 663.302 18.984 665.606 19.961 666.606 21.906 667.114 22.887 667.372 24.141 667.372 25.672 l 667.372 32.234 b 667.372 33.84 667.544 35.422 667.888 36.984 l 663.653 36.984 b 663.517 36.164 663.411 35.234 663.341 34.203 l 663.278 34.203 b 662.153 35.734 660.481 36.637 658.263 36.906 657.864 36.961 657.485 36.984 657.122 36.984 654.755 36.984 653.126 36.121 652.231 34.391 651.825 33.609 651.622 32.711 651.622 31.688 651.622 29.156 652.88 27.32 655.403 26.172 657.028 25.434 659.032 25.062 661.419 25.062 l 662.903 25.062 662.903 24.984 b 662.903 23.684 662.454 22.871 661.559 22.547 661.079 22.371 660.423 22.281 659.591 22.281 657.349 22.281 655.231 22.711 653.231 23.562 l 652.575 20.516 b 654.763 19.496 657.138 18.984 659.7 18.984 m 674.288 18.984 l 678.554 18.984 678.616 22.734 678.694 22.734 b 680.757 20.234 683.495 18.984 686.913 18.984 l 686.913 22.594 b 683.421 22.594 681.038 23.68 679.757 25.844 679.163 26.844 678.866 27.992 678.866 29.281 l 678.866 36.984 674.288 36.984 m 696.237 29 b 696.393 31.086 697.307 32.508 698.987 33.266 699.694 33.59 700.475 33.75 701.331 33.75 703.049 33.75 704.729 33.293 706.377 32.375 l 707.409 35.625 b 705.323 36.531 703.147 36.984 700.877 36.984 697.741 36.984 695.335 35.938 693.659 33.844 692.397 32.273 691.768 30.32 691.768 27.984 691.768 24.477 692.96 21.934 695.346 20.359 696.76 19.445 698.456 18.984 700.424 18.984 704.12 18.984 706.635 20.324 707.971 23 708.565 24.273 708.862 25.75 708.862 27.438 708.862 27.961 708.823 28.48 708.752 29 m 696.237 25.984 l 704.627 25.984 b 704.604 23.891 703.612 22.664 701.643 22.297 701.268 22.227 700.877 22.188 700.471 22.188 698.471 22.188 697.163 22.945 696.549 24.453 696.362 24.922 696.256 25.434 696.237 25.984 m 721.998 19.703 l 728.155 19.703 728.155 22.984 721.998 22.984 721.998 30.203 b 721.998 31.934 722.342 32.98 723.03 33.344 723.35 33.5 723.799 33.578 724.373 33.578 725.475 33.578 726.506 33.387 727.467 33 l 728.061 36.297 b 726.631 36.758 725.096 36.984 723.452 36.984 720.608 36.984 718.784 36.09 717.983 34.297 717.616 33.453 717.436 32.352 717.436 30.984 l 717.436 22.984 713.717 22.984 713.717 19.703 717.436 19.703 717.436 12.984 721.998 12.984 m 738.234 31.469 b 738.234 32.762 738.796 33.555 739.921 33.844 740.171 33.887 740.425 33.906 740.687 33.906 742.331 33.906 743.612 33.246 744.53 31.922 745.062 31.109 745.327 30.211 745.327 29.219 l 745.327 27.984 743.843 27.984 b 740.999 27.984 739.222 28.734 738.515 30.234 738.327 30.609 738.234 31.023 738.234 31.469 m 742.124 18.984 b 745.726 18.984 748.03 19.961 749.03 21.906 749.538 22.887 749.796 24.141 749.796 25.672 l 749.796 32.234 b 749.796 33.84 749.968 35.422 750.312 36.984 l 746.077 36.984 b 745.941 36.164 745.835 35.234 745.765 34.203 l 745.702 34.203 b 744.577 35.734 742.905 36.637 740.687 36.906 740.288 36.961 739.909 36.984 739.546 36.984 737.179 36.984 735.55 36.121 734.655 34.391 734.249 33.609 734.046 32.711 734.046 31.688 734.046 29.156 735.304 27.32 737.827 26.172 739.452 25.434 741.456 25.062 743.843 25.062 l 745.327 25.062 745.327 24.984 b 745.327 23.684 744.878 22.871 743.984 22.547 743.503 22.371 742.847 22.281 742.015 22.281 739.773 22.281 737.655 22.711 735.655 23.562 l 734.999 20.516 b 737.187 19.496 739.562 18.984 742.124 18.984 m 773.873 29.016 l 773.811 29.016 773.811 36.984 769.342 36.984 769.342 11.984 773.811 11.984 773.811 26.016 773.873 26.016 780.686 18.984 786.014 18.984 777.529 27.531 786.186 36.984 780.857 36.984 m 799.578 33.625 b 801.754 33.625 803.141 32.539 803.734 30.359 803.922 29.652 804.016 28.859 804.016 27.984 804.016 24.977 803.004 23.168 800.984 22.562 800.547 22.43 800.078 22.359 799.578 22.359 797.348 22.359 795.957 23.484 795.406 25.734 795.25 26.422 795.172 27.172 795.172 27.984 795.172 31.039 796.191 32.859 798.234 33.453 798.672 33.57 799.117 33.625 799.578 33.625 m 799.578 18.984 b 802.879 18.984 805.32 20.133 806.906 22.422 807.957 23.953 808.484 25.809 808.484 27.984 808.484 31.359 807.312 33.852 804.969 35.453 803.476 36.477 801.68 36.984 799.578 36.984 796.254 36.984 793.812 35.828 792.25 33.516 791.219 31.984 790.703 30.141 790.703 27.984 790.703 24.559 791.867 22.059 794.203 20.484 795.691 19.484 797.484 18.984 799.578 18.984 m 818.73 29.016 l 818.667 29.016 818.667 36.984 814.198 36.984 814.198 11.984 818.667 11.984 818.667 26.016 818.73 26.016 825.542 18.984 830.87 18.984 822.386 27.531 831.042 36.984 825.714 36.984 m 844.435 33.625 b 846.61 33.625 847.997 32.539 848.591 30.359 848.778 29.652 848.872 28.859 848.872 27.984 848.872 24.977 847.86 23.168 845.841 22.562 845.403 22.43 844.935 22.359 844.435 22.359 842.204 22.359 840.813 23.484 840.263 25.734 840.106 26.422 840.028 27.172 840.028 27.984 840.028 31.039 841.048 32.859 843.091 33.453 843.528 33.57 843.974 33.625 844.435 33.625 m 844.435 18.984 b 847.735 18.984 850.177 20.133 851.763 22.422 852.813 23.953 853.341 25.809 853.341 27.984 853.341 31.359 852.169 33.852 849.825 35.453 848.333 36.477 846.536 36.984 844.435 36.984 841.11 36.984 838.669 35.828 837.106 33.516 836.075 31.984 835.56 30.141 835.56 27.984 835.56 24.559 836.724 22.059 839.06 20.484 840.548 19.484 842.341 18.984 844.435 18.984 m 858.883 18.984 l 863.149 18.984 863.211 22.734 863.289 22.734 b 865.352 20.234 868.09 18.984 871.508 18.984 l 871.508 22.594 b 868.016 22.594 865.633 23.68 864.352 25.844 863.758 26.844 863.461 27.992 863.461 29.281 l 863.461 36.984 858.883 36.984 m 885.238 33.625 b 887.414 33.625 888.8 32.539 889.394 30.359 889.582 29.652 889.675 28.859 889.675 27.984 889.675 24.977 888.664 23.168 886.644 22.562 886.207 22.43 885.738 22.359 885.238 22.359 883.007 22.359 881.617 23.484 881.066 25.734 880.91 26.422 880.832 27.172 880.832 27.984 880.832 31.039 881.851 32.859 883.894 33.453 884.332 33.57 884.777 33.625 885.238 33.625 m 885.238 18.984 b 888.539 18.984 890.98 20.133 892.566 22.422 893.617 23.953 894.144 25.809 894.144 27.984 894.144 31.359 892.972 33.852 890.629 35.453 889.136 36.477 887.339 36.984 885.238 36.984 881.914 36.984 879.472 35.828 877.91 33.516 876.879 31.984 876.363 30.141 876.363 27.984 876.363 24.559 877.527 22.059 879.863 20.484 881.351 19.484 883.144 18.984 885.238 18.984 m 912.144 18.984 l 916.332 18.984 916.41 21.516 916.472 21.516 b 917.71 20.102 919.332 19.277 921.332 19.047 921.621 19.008 921.91 18.984 922.191 18.984 925.003 18.984 926.808 20.211 927.613 22.656 928.007 23.812 928.207 25.273 928.207 27.031 l 928.207 36.984 923.8 36.984 923.8 27.297 b 923.8 24.809 923.378 23.262 922.535 22.656 922.074 22.355 921.445 22.203 920.644 22.203 919.488 22.203 918.488 22.828 917.644 24.078 916.957 25.09 916.613 26.195 916.613 27.391 l 916.613 36.984 912.144 36.984 m 942.451 33.625 b 944.627 33.625 946.014 32.539 946.608 30.359 946.795 29.652 946.889 28.859 946.889 27.984 946.889 24.977 945.877 23.168 943.858 22.562 943.42 22.43 942.951 22.359 942.451 22.359 940.221 22.359 938.83 23.484 938.279 25.734 938.123 26.422 938.045 27.172 938.045 27.984 938.045 31.039 939.065 32.859 941.108 33.453 941.545 33.57 941.99 33.625 942.451 33.625 m 942.451 18.984 b 945.752 18.984 948.194 20.133 949.779 22.422 950.83 23.953 951.358 25.809 951.358 27.984 951.358 31.359 950.186 33.852 947.842 35.453 946.35 36.477 944.553 36.984 942.451 36.984 939.127 36.984 936.686 35.828 935.123 33.516 934.092 31.984 933.576 30.141 933.576 27.984 933.576 24.559 934.74 22.059 937.076 20.484 938.565 19.484 940.358 18.984 942.451 18.984 m 974.061 29.016 l 973.998 29.016 973.998 36.984 969.529 36.984 969.529 11.984 973.998 11.984 973.998 26.016 974.061 26.016 980.873 18.984 986.201 18.984 977.717 27.531 986.373 36.984 981.045 36.984 m 995.422 31.469 b 995.422 32.762 995.984 33.555 997.109 33.844 997.359 33.887 997.613 33.906 997.875 33.906 999.519 33.906 1000.801 33.246 1001.719 31.922 1002.25 31.109 1002.516 30.211 1002.516 29.219 l 1002.516 27.984 1001.031 27.984 b 998.187 27.984 996.41 28.734 995.703 30.234 995.516 30.609 995.422 31.023 995.422 31.469 m 999.312 18.984 b 1002.914 18.984 1005.219 19.961 1006.219 21.906 1006.726 22.887 1006.984 24.141 1006.984 25.672 l 1006.984 32.234 b 1006.984 33.84 1007.156 35.422 1007.5 36.984 l 1003.266 36.984 b 1003.129 36.164 1003.023 35.234 1002.953 34.203 l 1002.891 34.203 b 1001.766 35.734 1000.094 36.637 997.875 36.906 997.476 36.961 997.098 36.984 996.734 36.984 994.367 36.984 992.738 36.121 991.844 34.391 991.437 33.609 991.234 32.711 991.234 31.688 991.234 29.156 992.492 27.32 995.016 26.172 996.641 25.434 998.644 25.062 1001.031 25.062 l 1002.516 25.062 1002.516 24.984 b 1002.516 23.684 1002.066 22.871 1001.172 22.547 1000.691 22.371 1000.035 22.281 999.203 22.281 996.961 22.281 994.844 22.711 992.844 23.562 l 992.187 20.516 b 994.375 19.496 996.75 18.984 999.312 18.984 m 1017.166 27.953 b 1017.166 30.477 1017.889 32.18 1019.338 33.062 1019.908 33.418 1020.526 33.594 1021.182 33.594 1022.951 33.594 1024.182 32.727 1024.869 30.984 1025.19 30.164 1025.354 29.215 1025.354 28.141 l 1025.354 27.797 b 1025.354 25.266 1024.572 23.59 1023.01 22.766 1022.436 22.484 1021.826 22.344 1021.182 22.344 1019.213 22.344 1017.967 23.434 1017.447 25.609 1017.26 26.32 1017.166 27.102 1017.166 27.953 m 1019.916 18.984 b 1022.229 18.984 1024.088 19.891 1025.494 21.703 l 1025.557 21.703 1025.666 18.984 1029.822 18.984 1029.822 34.578 b 1029.779 40.848 1026.651 43.984 1020.432 43.984 1018.346 43.984 1016.401 43.645 1014.588 42.969 l 1015.385 39.875 b 1017.049 40.395 1018.697 40.656 1020.322 40.656 1022.623 40.656 1024.119 39.992 1024.807 38.672 1025.213 37.867 1025.416 36.793 1025.416 35.438 l 1025.416 34.375 1025.354 34.375 b 1024.018 36.117 1022.205 36.984 1019.916 36.984 1017.643 36.984 1015.842 36.008 1014.51 34.047 1013.416 32.402 1012.869 30.383 1012.869 27.984 1012.869 23.828 1014.119 21.086 1016.619 19.75 1017.576 19.242 1018.674 18.984 1019.916 18.984 m 1037.601 36.984 l 1037.601 18.984 1042.304 18.984 1042.304 36.984 m 1037.601 16.062 l 1037.601 11.984 1042.304 11.984 1042.304 16.062"
        )
        for element, expected_element in zip(shape, expectedShape):
            for i in range(len(element.coordinates)):
                x, y = element.coordinates[i].x, element.coordinates[i].y
                x_expected, y_expected = (
                    expected_element.coordinates[i].x,
                    expected_element.coordinates[i].y,
                )
                check.almost_equal(x, x_expected, abs=max_deviation)
                check.almost_equal(y, y_expected, abs=max_deviation)
    else:
        raise NotImplementedError
